#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


from pyramid.i18n import TranslationStringFactory
_ = TranslationStringFactory('onf_website')


def includeme(config):
    """Pyramid include"""

    from .include import include_package
    include_package(config)

    # register custom permissions
    config.register_permission({'id': 'onf.ManageSiteRoot',
                                'title': _("ONF: Manage site root")})
    config.register_permission({'id': 'onf.ManageSite',
                                'title': _("ONF: Manage site")})
    config.register_permission({'id': 'onf.ManageTool',
                                'title': _("ONF: Manage tool")})
    config.register_permission({'id': 'onf.CreateContent',
                                'title': _("ONF: Create content")})
    config.register_permission({'id': 'onf.ManageContent',
                                'title': _("ONF: Manage content")})
    config.register_permission({'id': 'onf.CommentContent',
                                'title': _("ONF: Comment content")})
    config.register_permission({'id': 'onf.PublishContent',
                                'title': _("ONF: Publish content")})

    # register custom roles
    config.register_role({'id': 'onf.Webmaster',
                          'title': _("Webmaster (role)"),
                          'permissions': {'public', 'view', 'manage', 'system.view',
                                          'security.manage', 'security.manage_roles',
                                          'onf.ManageSiteRoot', 'onf.ManageSite', 'onf.ManageTool',
                                          'onf.CreateContent', 'onf.ManageContent', 'onf.CommentContent',
                                          'onf.PublishContent'},
                          'managers': {'system:admin', 'role:system.Manager', 'role:onf.Webmaster'}})
    config.register_role({'id': 'onf.Pilot',
                          'title': _("Pilot (role)"),
                          'permissions': {'public', 'view', 'manage', 'system.view',
                                          'security.manage_roles',
                                          'onf.ManageSite', 'onf.ManageTool', 'onf.CreateContent',
                                          'onf.ManageContent', 'onf.CommentContent', 'onf.PublishContent'},
                          'managers': {'system:admin', 'role:system.Manager', 'role:onf.Webmaster'}})
    config.register_role({'id': 'onf.Manager',
                          'title': _("Manager (role)"),
                          'permissions': {'public', 'view', 'manage', 'system.view',
                                          'security.manage_roles',
                                          'onf.ManageTool', 'onf.CreateContent', 'onf.ManageContent',
                                          'onf.CommentContent', 'onf.PublishContent'},
                          'managers': {'system:admin', 'role:system.Manager', 'role:onf.Webmaster', 'role:onf.Pilot'}})
    config.register_role({'id': 'onf.Contributor',
                          'title': _("Contributor (role)"),
                          'permissions': {'public', 'view', 'manage', 'system.view',
                                          'onf.CreateContent', 'onf.ManageContent', 'onf.CommentContent'},
                          'managers': {'system:admin', 'role:system.Manager', 'role:onf.Webmaster', 'role:onf.Pilot',
                                       'role:onf.Manager'}})
    config.register_role({'id': 'onf.Reader',
                          'title': _("Reader (role)"),
                          'permissions': {'public', 'view', 'manage', 'system.view',
                                          'onf.CommentContent'},
                          'managers': {'system:admin', 'role:system.Manager', 'role:onf.Webmaster', 'role:onf.Pilot',
                                       'role:onf.Manager', 'role:onf.Contributor'}})
    config.register_role({'id': 'onf.Operator',
                          'title': _("Operator (role)"),
                          'permissions': {'public', 'view', 'system.view'},
                          'managers': {'system:admin', 'role:system.Manager'}})
