#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
from pyramid.view import view_config
from onf_website.component.paragraph import HTMLParagraph
from onf_website.component.paragraph.interfaces import IParagraphContainerTarget, IHTMLParagraph, IParagraphContainer, \
    IBaseParagraph
from onf_website.component.paragraph.zmi.container import ParagraphContainerView
from onf_website.shared.common.interfaces import IWfSharedContent
from pyams_form.form import AJAXAddForm, AJAXEditForm
from pyams_form.security import ProtectedFormObjectMixin
from pyams_i18n.interfaces import II18n
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.interfaces.viewlet import IToolbarAddingMenu
from pyams_skin.layer import IPyAMSLayer
from pyams_skin.viewlet.toolbar import ToolbarMenuItem
from pyams_utils.traversing import get_parent
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogAddForm, AdminDialogEditForm

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces

# import packages
from z3c.form import field

from onf_website import _


#
# HTML paragraph
#

@viewlet_config(name='add-html-paragraph.menu', context=IParagraphContainerTarget, view=ParagraphContainerView,
                layer=IPyAMSLayer, manager=IToolbarAddingMenu, weight=50)
class HTMLParagraphAddMenu(ProtectedFormObjectMixin, ToolbarMenuItem):
    """HTML paragraph add menu"""

    label = _("Add HTML paragraph...")
    label_css_class = 'fa fa-fw fa-html5'
    url = 'add-html-paragraph.html'
    modal_target = True


@pagelet_config(name='add-html-paragraph.html', context=IParagraphContainerTarget, layer=IPyAMSLayer,
                permission='onf.ManageContent')
class HTMLParagraphAddForm(AdminDialogAddForm):
    """HTML paragraph add form"""

    legend = _("Add new HTML paragraph")
    dialog_class = 'modal-max'
    icon_css_class = 'fa fa-fw fa-html5'
    label_css_class = 'control-label col-md-2'
    input_css_class = 'col-md-10'

    fields = field.Fields(IHTMLParagraph).omit('__parent__', '__name__')
    ajax_handler = 'add-html-paragraph.json'
    edit_permission = 'onf.ManageContent'

    def updateWidgets(self, prefix=None):
        super(HTMLParagraphAddForm, self).updateWidgets(prefix)
        self.widgets['body'].label_css_class = 'textarea'

    def create(self, data):
        return HTMLParagraph()

    def add(self, object):
        IParagraphContainer(self.context)['none'] = object


@view_config(name='add-html-paragraph.json', context=IParagraphContainerTarget, request_type=IPyAMSLayer,
             permission='onf.ManageContent', renderer='json', xhr=True)
class HTMLParagraphAJAXAddForm(AJAXAddForm, HTMLParagraphAddForm):
    """HTML paragraph add form, JSON renderer"""

    def get_ajax_output(self, changes):
        return {'status': 'reload',
                'location': '#paragraphs.html'}


@pagelet_config(name='properties.html', context=IHTMLParagraph, layer=IPyAMSLayer, permission='onf.ManageContent')
class HTMLParagraphPropertiesEditForm(AdminDialogEditForm):
    """HTML paragraph properties edit form"""

    @property
    def title(self):
        content = get_parent(self.context, IWfSharedContent)
        return II18n(content).query_attribute('title', request=self.request)

    legend = _("Edit paragraph properties")
    dialog_class = 'modal-max'
    icon_css_class = 'fa fa-fw fa-html5'
    label_css_class = 'control-label col-md-2'
    input_css_class = 'col-md-10'

    fields = field.Fields(IHTMLParagraph).omit('__parent__', '__name__')
    ajax_handler = 'properties.json'
    edit_permission = 'onf.ManageContent'

    def updateWidgets(self, prefix=None):
        super(HTMLParagraphPropertiesEditForm, self).updateWidgets(prefix)
        self.widgets['body'].label_css_class = 'textarea'


@view_config(name='properties.json', context=IHTMLParagraph, request_type=IPyAMSLayer,
             permission='onf.ManageContent', renderer='json', xhr=True)
class HTMLParagraphPropertiesAJAXEditForm(AJAXEditForm, HTMLParagraphPropertiesEditForm):
    """HTML paragraph properties edit form, JSON renderer"""

    def get_ajax_output(self, changes):
        if 'title' in changes.get(IBaseParagraph, ()):
            return {'status': 'reload',
                    'location': '#paragraphs.html'}
        else:
            return super(HTMLParagraphPropertiesAJAXEditForm, self).get_ajax_output(changes)
