#
# -*- encoding: utf-8 -*-
#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.root.interfaces import ISiteRootRoles, ISiteRootConfiguration, ISiteRoot, \
    ISiteRootToolsConfiguration
from pyams_portal.interfaces import IPortalContext
from pyams_security.interfaces import IDefaultProtectionPolicy, IGrantedRoleEvent, ISecurityManager
from pyams_skin.interfaces.configuration import IStaticConfiguration
from pyams_utils.interfaces.site import IConfigurationFactory
from zope.annotation.interfaces import IAnnotations

# import packages
from persistent import Persistent
from pyams_security.property import RolePrincipalsFieldProperty
from pyams_security.security import ProtectedObject
from pyams_skin.configuration import Configuration, StaticConfiguration
from pyams_utils.adapter import adapter_config
from pyams_utils.registry import get_utility
from pyams_utils.site import BaseSiteRoot
from pyams_utils.traversing import get_parent
from pyramid.events import subscriber
from zope.interface import implementer, Interface


@adapter_config(context=(ISiteRoot, Interface, Interface), provides=IStaticConfiguration)
class SiteRootStaticConfiguration(StaticConfiguration):
    """Site root static configuration"""

    application_package = 'onf_website'
    application_name = 'Atelier éditorial'


@implementer(IDefaultProtectionPolicy, ISiteRoot, ISiteRootRoles, IPortalContext)
class SiteRoot(ProtectedObject, BaseSiteRoot):
    """Main site root"""

    __roles__ = ('system.Manager', 'onf.Webmaster', 'onf.Operator')

    roles_interface = ISiteRootRoles

    managers = RolePrincipalsFieldProperty(ISiteRootRoles['managers'])
    webmasters = RolePrincipalsFieldProperty(ISiteRootRoles['webmasters'])
    operators = RolePrincipalsFieldProperty(ISiteRootRoles['operators'])


@implementer(ISiteRootConfiguration)
class SiteRootConfiguration(Configuration):
    """Site root configuration"""


@adapter_config(context=ISiteRoot, provides=IConfigurationFactory)
def SiteRootConfigurationFactory(context):
    return SiteRootConfiguration


@subscriber(IGrantedRoleEvent)
def handle_granted_role(event):
    """Add principals to operators group when a role is granted"""
    role_id = event.role_id
    if (role_id == 'onf.Operator') or (not role_id.startswith('onf.')):
        return
    root = get_parent(event.object, ISiteRoot)
    if not root.operators:
        return
    security = get_utility(ISecurityManager)
    for principal_id in root.operators:
        group = security.get_principal(principal_id, info=False)
        if event.principal_id not in group.principals:
            group.principals = group.principals | {event.principal_id}


#
# Tools configuration
#

@implementer(ISiteRootToolsConfiguration)
class SiteRootToolsConfiguration(Persistent):
    """Site root tools configuration"""

    tools_name = None
    news_tool_name = None


SITEROOT_TOOLS_CONFIGURATION_KEY = 'onf_website.tools.configuration'


@adapter_config(context=ISiteRoot, provides=ISiteRootToolsConfiguration)
def site_root_tools_configuration_factory(context):
    """Site root tools configuration factory"""
    annotations = IAnnotations(context)
    config = annotations.get(SITEROOT_TOOLS_CONFIGURATION_KEY)
    if config is None:
        config = annotations[SITEROOT_TOOLS_CONFIGURATION_KEY] = SiteRootToolsConfiguration()
    return config
