#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
from onf_website.shared.common.zmi import WfSharedContentHeaderAdapter

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.shared.common.interfaces import IWfSharedContent
from pyams_form.interfaces.form import IWidgetForm
from pyams_skin.interfaces import IInnerPage, IPageHeader
from pyams_skin.layer import IPyAMSLayer
from pyams_zmi.interfaces.menu import IContentManagementMenu, IPropertiesMenu
from pyams_zmi.layer import IAdminLayer

# import packages
from pyams_form.form import AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.viewlet.menu import MenuItem
from pyams_utils.adapter import adapter_config
from pyams_viewlet.manager import viewletmanager_config
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminEditForm
from pyramid.view import view_config
from z3c.form import field
from zope.interface import implementer

from onf_website import _


#
# Content properties
#

@viewlet_config(name='properties.menu', context=IWfSharedContent, layer=IAdminLayer,
                manager=IContentManagementMenu, permission='onf.ManageContent', weight=10)
@viewletmanager_config(name='properties.menu', layer=IAdminLayer, provides=IPropertiesMenu)
@implementer(IPropertiesMenu)
class SharedContentPropertiesMenu(MenuItem):
    """Shared content properties menu"""

    label = _("Properties")
    icon_class = 'fa-edit'
    url = '#properties.html'


@pagelet_config(name='properties.html', context=IWfSharedContent, layer=IPyAMSLayer, permission='onf.ManageContent')
@implementer(IWidgetForm, IInnerPage)
class SharedContentPropertiesEditForm(AdminEditForm):
    """Shared content properties edit form"""

    legend = _("Content properties")

    fields = field.Fields(IWfSharedContent).omit('__parent__', '__name__', 'owner')
    ajax_handler = 'properties.json'

    def updateWidgets(self, prefix=None):
        super(SharedContentPropertiesEditForm, self).updateWidgets(prefix)
        if 'description' in self.widgets:
            self.widgets['description'].label_css_class = 'textarea'


@view_config(name='properties.json', context=IWfSharedContent, request_type=IPyAMSLayer,
             permission='onf.ManageContent', renderer='json', xhr=True)
class SharedContentPropertiesAJAXEditForm(AJAXEditForm, SharedContentPropertiesEditForm):
    """Shared content properties edit form, JSON renderer"""


@adapter_config(context=(IWfSharedContent, IAdminLayer, SharedContentPropertiesEditForm), provides=IPageHeader)
class SharedContentPropertiesHeaderAdapter(WfSharedContentHeaderAdapter):
    """Shared content properties header adapter"""

    icon_class = 'fa fa-fw fa-edit'
