#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
from pyramid.view import view_config
from onf_website.component.extfile.interfaces import IExtFileContainerTarget, IExtFileContainer
from onf_website.component.links.interfaces import ILinkContainerTarget, ILinkContainer
from pyams_i18n.interfaces import II18n
from pyams_utils.traversing import get_parent
from pyams_utils.url import absolute_url

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_form.interfaces.form import IForm
from pyams_skin.interfaces.tinymce import ITinyMCEConfiguration
from pyams_skin.layer import IPyAMSLayer

# import packages
from pyams_utils.adapter import adapter_config, ContextRequestAdapter
from zope.interface import Interface


@view_config(name='get-files-list.json', context=Interface, request_type=IPyAMSLayer,
             renderer='json', xhr=True)
def get_files_list(request):
    """Get container files in JSON format for TinyMCE editor"""
    target = get_parent(request.context, IExtFileContainerTarget)
    if target is None:
        return []
    container = IExtFileContainer(target)
    return sorted([{'title': II18n(file).query_attribute('title', request=request),
                    'value': absolute_url(II18n(file).query_attribute('data', request=request), request)}
                   for file in container.values()],
                  key=lambda x: x['title'])


@view_config(name='get-images-list.json', context=Interface, request_type=IPyAMSLayer,
             renderer='json', xhr=True)
def get_images_list(request):
    """Get container images in JSON format for TinyMCE editor"""
    target = get_parent(request.context, IExtFileContainerTarget)
    if target is None:
        return []
    container = IExtFileContainer(target)
    return sorted([{'title': II18n(img).query_attribute('title', request=request),
                    'value': absolute_url(II18n(img).query_attribute('data', request=request), request)}
                   for img in container.images],
                  key=lambda x: x['title'])


@view_config(name='get-links-list.json', context=Interface, request_type=IPyAMSLayer,
             renderer='json', xhr=True)
def get_links_list(request):
    """Get links list in JSON format for TinyMCE editor"""
    result = []
    target = get_parent(request.context, IExtFileContainerTarget)
    if target is not None:
        container = IExtFileContainer(target)
        result.extend([{'title': II18n(file).query_attribute('title', request=request),
                        'value': absolute_url(II18n(file).query_attribute('data', request=request), request)}
                       for file in container.values()])
    target = get_parent(request.context, ILinkContainerTarget)
    if target is not None:
        container = ILinkContainer(target)
        result.extend([{'title': II18n(link).query_attribute('title', request=request),
                        'value': link.get_editor_url()}
                       for link in container.values()])
    return sorted(result, key=lambda x: x['title'])


@adapter_config(context=(IForm, IPyAMSLayer),
                provides=ITinyMCEConfiguration)
class TinyMCEEditorConfiguration(ContextRequestAdapter):
    """TinyMCE editor configuration"""

    @property
    def configuration(self):
        return {'ams-plugins': 'editor',
                'ams-plugin-editor-src': '/--static--/onf_website/js/tinymce{MyAMS.devext}.js',
                'ams-plugin-editor-async': 'false',
                'ams-tinymce-external-plugins': 'onflinks',
                'ams-tinymce-plugin-onflinks': '/--static--/onf_website/js/tinymce/onflinks/plugin{MyAMS.devext}.js',
                'ams-tinymce-init-callback': 'ONF.TinyMCE.initEditor'}
