#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from hypatia.interfaces import ICatalog
from onf_website.shared.common.interfaces import ISharedTool
from pyams_i18n.interfaces import II18n
from pyams_skin.interfaces.viewlet import ITopLinksViewletManager
from pyams_zmi.layer import IAdminLayer

# import packages
from hypatia.catalog import CatalogQuery
from hypatia.query import Any
from pyams_catalog.query import CatalogResultSet
from pyams_skin.viewlet.toplinks import TopLinksViewlet, TopLinksMenu
from pyams_utils.list import unique
from pyams_utils.registry import get_local_registry, query_utility
from pyams_utils.url import absolute_url
from pyams_viewlet.viewlet import viewlet_config

from onf_website import _


@viewlet_config(name='shared-tools.menu', layer=IAdminLayer, manager=ITopLinksViewletManager, weight=30)
class SharedToolsMenu(TopLinksViewlet):
    """Shared tools menu"""

    label = ''
    css_class = 'top-menu margin-top-10'
    dropdown_label = _("Shared tools")

    def update(self):
        super(SharedToolsMenu, self).update()
        registry = get_local_registry()
        for name, tool in registry.getUtilitiesFor(ISharedTool):
            menu = TopLinksMenu(self.context, self.request, self.__parent__, self)
            menu.label = II18n(tool).query_attribute('title', request=self.request) or tool.__name__
            menu.url = absolute_url(tool, self.request, 'admin.html#dashboard.html')
            self.viewlets.append(menu)


@viewlet_config(name='user-roles.menu', layer=IAdminLayer, manager=ITopLinksViewletManager, weight=90)
class UserRolesMenu(TopLinksViewlet):
    """User roles menu"""

    label = ''
    css_class = 'top-menu margin-top-10'
    dropdown_label = _("My roles")

    def update(self):
        super(UserRolesMenu, self).update()
        catalog = query_utility(ICatalog)
        params = Any(catalog['role:contributor'], {self.request.principal.id})
        for tool in sorted(unique(CatalogResultSet(CatalogQuery(catalog).query(params))),
                           key=lambda x: II18n(x).query_attribute('title', request=self.request)):
            menu = TopLinksMenu(self.context, self.request, self.__parent__, self)
            menu.label = II18n(tool).query_attribute('title', request=self.request) or tool.__name__
            menu.url = absolute_url(tool, self.request, 'admin.html#dashboard.html')
            self.viewlets.append(menu)
